@@ -70,19 +70,17 @@ class RenogyChargeController(minimalmodbus.Instrument):
 
     def get_battery_temperature(self):
         """battery temperature"""
-        register_value = self.read_register(0x0103, 0, 3)
-
-        battery_temperature_sign = extract_bits(register_value, 15, 1)
-        battery_temperature = extract_bits(register_value, 8, 7)
+        register_value = self.read_register(0x0103, 0, 3) & 0x00ff & 0x0ff
+        battery_temperature = register_value & 0x00ff & 0x0ff
+        battery_temperature_sign = register_value & 0x00ff >> 7
         battery_temperature = -battery_temperature if battery_temperature_sign == 1 else battery_temperature
         return battery_temperature
 
     def get_controller_temperature(self):
         """Temperature inside equipment"""
-        register_value = self.read_register(0x0103, 0, 3)
-
-        controller_temperature = extract_bits(register_value, 0, 7)
-        controller_temperature_sign = extract_bits(register_value, 7, 1)
+        register_value = self.read_register(0x0103, 0, 3) >> 8
+        controller_temperature = register_value & 0x0ff
+        controller_temperature_sign = register_value >> 7
         controller_temperature = -controller_temperature if controller_temperature_sign == 1 else controller_temperature
         return controller_temperature
 
